@@ -1,3 +1,4 @@
+from re import I
 import sympy
 
 import IPython
@@ -8,8 +9,7 @@ Documento = []
 
 #_print_Symbol
 
-from IPython.display import Image
-display(Image(url='https://i.gyazo.com/0842e5162257727d5b10fd6b4abfdab9.png'))
+IPython.display.Image(url='https://i.gyazo.com/0842e5162257727d5b10fd6b4abfdab9.png')
 
 def Inicializar(n):
   global DatosList,Orden,Estilo
